import { Hono } from "hono";
import { serveStatic, createBunWebSocket } from "hono/bun";
import type { ServerWebSocket } from "hono";
import {
  chatRoom,
  createMessageString,
  type Chatter,
  type Message

} from "./chat-room.ts";

const app = new Hono();
const users: string[] = [];

// Set up the chat socket
const { upgradeWebSocket, websocket } = createBunWebSocket<ServerWebSocket>();
app.get("/chat-socket", upgradeWebSocket((c) => {
  return {
    onMessage(event, ws) {
      const data = JSON.parse(event.data);

      if (!chatters.find(c => c.name == data.chatter.name)) {
        chatters.push(data.chatter);
      }

      const message: Message = {
        chatter: { data.chatter },
        message: data.message,
        timestamp: Date.now() as string;
      };

      chatRoom.addMessage(message);

      ws.send(JSON.stringify({ message: createMessageString(message) }));
    },
    onClose() {
      console.log("Connection closed.");
    },
    onError(event) {
      console.log(event);
    }
  }
}));

// get the HTML and JS from the static repo
app.use("/", serveStatic({ path: "/static/index.html" }));
app.use("/*", serveStatic({ root: "/static" }));

Bun.serve({
  fetch: app.fetch,
  websocket
});
